@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from qubell.api.provider import log_routes_stat
+import logging
 
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
@@ -25,4 +26,8 @@ This module keeps Integration Tests, live Platform required
 
 import atexit
 
-atexit.register(log_routes_stat)
\ No newline at end of file
+atexit.register(log_routes_stat)
+
+logger = logging.getLogger("qubell")
+logging.getLogger().setLevel(logging.INFO)
+logger.setLevel(logging.INFO)
\ No newline at end of file
