@@ -61,9 +61,11 @@ class Revision(Entity, InstanceRouter):
     def json(self):
         return self._router.get_revision(org_id=self.organizationId, app_id=self.applicationId, rev_id=self.id).json()
 
-    def delete(self):
-        self._router.delete_revision(org_id=self.organizationId, app_id=self.applicationId, rev_id=self.id)
-        return True
+    def delete(self, force=True):
+        if force:
+            return self._router.delete_revision(org_id=self.organizationId, app_id=self.applicationId, rev_id=self.id, force="true")
+        else:
+            return self._router.delete_revision(org_id=self.organizationId, app_id=self.applicationId, rev_id=self.id, force="false")
 
 
 class RevisionList(EntityList, InstanceRouter):
