@@ -22,9 +22,12 @@ import yaml
 import simplejson as json
 
 from qubell.api.private import exceptions
-from qubell.api.provider.router import ROUTER as router
+from qubell.api.tools import retry
 
-#ToDo: Move to Globals
+__all__ = ['COBALT_SECURE_STORE_TYPE', 'WORKFLOW_SERVICE_TYPE', 'SHARED_INSTANCE_CATALOG_TYPE',
+           'STATIC_RESOURCE_POOL_TYPE', 'CLOUD_ACCOUNT_TYPE']
+
+# ToDo: Move to Globals
 
 COBALT_SECURE_STORE_TYPE = 'builtin:cobalt_secure_store'
 WORKFLOW_SERVICE_TYPE = 'builtin:workflow_service'
@@ -43,24 +46,42 @@ system_application_parameters = {
     SHARED_INSTANCE_CATALOG_TYPE: 'configuration.shared-instances',
     STATIC_RESOURCE_POOL_TYPE: 'configuration.resources'}
 
-
-
 SHARED_INSTANCES_PARAMETER_NAME = system_application_parameters[SHARED_INSTANCE_CATALOG_TYPE]
 
 
 # noinspection PyUnresolvedReferences
 class ServiceMixin(object):
     def regenerate(self):
-        return router.post_service_generate(org_id=self.organizationId, instance_id=self.instanceId).json()
+        return self._router.post_service_generate(org_id=self.organizationId, instance_id=self.instanceId).json()
+
+    def list_keys(self):
+        return self._router.get_service_keys(org_id=self.organizationId, instance_id=self.instanceId).json()
+
+    def get_public_key(self, key_id=None):
+        if not key_id:
+            key_id = self.userData['defaultKey']
+        return self._router.get_service_public_key(org_id=self.organizationId,
+                                                   instance_id=self.instanceId, key_id=key_id).text
 
     def add_shared_instance(self, revision, instance):
         payload = json.dumps({"revisionNameId": revision.nameId,
                               "instanceId": instance.instanceId})
-        router.post_instance_shared(org_id=self.organizationId, env_id=instance.environment.id, data=payload)
+        self._router.post_instance_shared(org_id=self.organizationId, env_id=instance.environment.id, data=payload)
+        @retry(5, 1, 2)
+        def wait_config_propagate():
+            return self.get_shared_instance_id(revision.nameId) == instance.instanceId
+        wait_config_propagate()
+
+    def get_shared_instance_id(self, revision):
+        payload = json.dumps({"arguments": {"revision": revision}, "includeIntermediate": False})
+        result = self._router.post_service_command(org_id=self.organizationId, instance_id=self.instanceId,
+                                                   command_name="strategy.get-shared-instance", data=payload)
+        return json.loads(result.content)[0].get("instance")
 
     def remove_shared_instance(self, instance):
         params = self.parameters
         if SHARED_INSTANCES_PARAMETER_NAME in params:
+            # noinspection PyBroadException
             try:
                 # Param could contain invalid yaml
                 old = yaml.safe_load(params[SHARED_INSTANCES_PARAMETER_NAME])
@@ -87,4 +108,4 @@ class ServiceMixin(object):
         raw = self.json()
         if 'templateId' in raw:
             return raw['templateId'] == COBALT_SECURE_STORE_TYPE
-        return False
\ No newline at end of file
+        return False
