@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import re
+import functools
 
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
@@ -42,6 +43,7 @@ def retry(tries=10, delay=1, backoff=2, retry_exception=None):
     catching_mode = bool(retry_exception)
 
     def deco_retry(f):
+        @functools.wraps(f)
         def f_retry(*args, **kwargs):
             mtries, mdelay = tries, delay
 
@@ -67,19 +69,21 @@ def retry(tries=10, delay=1, backoff=2, retry_exception=None):
         return f_retry
     return deco_retry
 
-def waitForStatus(instance, final='Running', accepted=None, timeout=(20, 10, 1)):
+def waitForStatus(instance, final='Active', accepted=None, timeout=(20, 10, 1)):
     started = time.time()
     info = '%s (%s)' % (instance.name, instance.id)
 
     if not accepted: accepted = ['Requested']
 
+    if not isinstance(final, list): final = [final]
+
     @retry(3, 1, 2)  # max = 1 + 2 + 4 = 7 seconds + routes time
     def projection_update_monitor():
         """
         We have to deal with lag when projection updates instance.
         :return:
         """
-        return instance.status != final or instance._is_projection_updated_instance()
+        return instance.status not in final or instance._is_projection_updated_instance()
     projection_update_monitor()
 
     @retry(*timeout)  # ask status 20 times every 10 sec.
@@ -104,17 +108,15 @@ def waitForStatus(instance, final='Running', accepted=None, timeout=(20, 10, 1))
     if cur_status in final:
         return True
     elif cur_status in ['Error']:
-        log.error("\n\n\nInstance didn't get '{0}' status, current status :'{1}'. \n\n"
+        log.error("\n\n\nInstance didn't get one of {0} statuses, current status :'{1}'. \n\n"
                   "Instance: {2} ({3})\n"
-                  "Application: {4} ({5})\n"
-                  "Organization: {6} ({7})\n"
-                  "Timeout: {8} sec\n"
+                  "Organization: {4} ({5})\n"
+                  "Timeout: {6} sec\n"
                   "---------------- Error Text ---------------------\n"
-                  "{9}"
+                  "{7}"
                   "\n-------------- Error Text End -----------------\n".format(
             final, cur_status,
             instance.name, instance.id,
-            instance.application.name, instance.application.id,
             instance.organization.name, instance.organization.id,
             timeout[0]*timeout[1]*timeout[2],
             instance.error))
@@ -124,14 +126,12 @@ def waitForStatus(instance, final='Running', accepted=None, timeout=(20, 10, 1))
                   "\n------------------ End of ActivityLog -----------------\n"
                   % instance.get_activitylog(severity=['ERROR', 'INFO']))
     else:
-        log.error("\n\n\nInstance didn't get '{0}' status, current status :'{1}'. \n\n"
+        log.error("\n\n\nInstance didn't get one of {0} statuses, current status :'{1}'. \n\n"
                   "Instance: {2} ({3})\n"
-                  "Application: {4} ({5})\n"
-                  "Organization: {6} ({7})\n"
-                  "Timeout: {8} sec\n\n".format(
+                  "Organization: {4} ({5})\n"
+                  "Timeout: {6} sec\n\n".format(
             final, cur_status,
             instance.name, instance.id,
-            instance.application.name, instance.application.id,
             instance.organization.name, instance.organization.id,
             timeout[0]*timeout[1]*timeout[2]))
         log.debug(instance.get_activitylog(severity=['ERROR', 'INFO']))
@@ -245,4 +245,4 @@ def lazy(func):
 
 def is_bson_id(bson_id):
     id_pattern = u'[A-Fa-f0-9]{24}'
-    return re.match(id_pattern, unicode(bson_id))
\ No newline at end of file
+    return re.match(id_pattern, unicode(bson_id))
